;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "starling" "20251029.707"
  "Starling bank interaction."
  '((emacs "29.1")
    (plz   "0.7.2"))
  :url "https://codeberg.org/draxil/starling-el"
  :commit "298186dc003052051cbcac08b270afb2b1f4f2b9"
  :revdesc "298186dc0030"
  :keywords '("data" "applications" "banking")
  :authors '(("Joe Higton" . "draxil@gmail.com"))
  :maintainers '(("Joe Higton" . "draxil@gmail.com")))
